@@ -1,4 +1,8 @@
-$:.unshift File.dirname(__FILE__)     # For use/testing when no gem is installed
+# Bail out before loading anything unless this flag is set.
+#
+# We are doing this to guard against bundler autoloading because there is
+# no value in loading god in most processes.
+if $load_god
 
 # core
 require 'stringio'
@@ -47,6 +51,7 @@ require 'god/conditions/http_response_code'
 require 'god/conditions/disk_usage'
 require 'god/conditions/complex'
 require 'god/conditions/file_mtime'
+require 'god/conditions/file_touched'
 require 'god/conditions/socket_responding'
 
 require 'god/socket'
@@ -151,7 +156,7 @@ end
 
 module God
   # The String version number for this package.
-  VERSION = '0.12.1'
+  VERSION = '0.13.2'
 
   # The Integer number of lines of backlog to keep for the logger.
   LOG_BUFFER_SIZE_DEFAULT = 100
@@ -726,7 +731,7 @@ module God
   # private
 
   # Match a shortened pattern against a list of String candidates.
-  # The pattern is expanded into a regular expression by 
+  # The pattern is expanded into a regular expression by
   # inserting .* between each character.
   #
   # pattern - The String containing the abbreviation.
@@ -756,3 +761,5 @@ end
 at_exit do
   God.at_exit if $run
 end
+
+end
